@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,13 +29,13 @@
 #include <tools/debug.hxx>
 #include <rtl/math.hxx>
 #include <bf_svtools/itemprop.hxx>
+#include <vcl/svapp.hxx>
 
 #include "dptabsrc.hxx"
 #include "dptabdat.hxx"
 #include "global.hxx"
 #include "collect.hxx"
 #include "datauno.hxx"		// ScDataUnoConversion
-#include "unoguard.hxx"
 #include "miscuno.hxx"
 #include "unonames.hxx"
 #include "dptabres.hxx"
@@ -42,12 +43,8 @@
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/sheet/DataPilotFieldOrientation.hpp>
 
-#ifndef _UNOTOOLS_CALENDARWRAPPER_HXX
 #include <unotools/calendarwrapper.hxx>
-#endif
-#ifndef _COM_SUN_STAR_I18N_CALENDARDISPLAYINDEX_HPP_
 #include <com/sun/star/i18n/CalendarDisplayIndex.hpp>
-#endif
 namespace binfilter {
 
 using namespace ::com::sun::star;
@@ -1092,7 +1089,7 @@ using namespace ::com::sun::star;
 /*N*/ uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPLevel::getPropertySetInfo()
 /*N*/ 														throw(uno::RuntimeException)
 /*N*/ {
-/*N*/ 	ScUnoGuard aGuard;
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 
 /*N*/ 	static SfxItemPropertyMap aDPLevelMap_Impl[] =
 /*N*/ 	{
@@ -1150,3 +1147,5 @@ using namespace ::com::sun::star;
 /*N*/ SC_IMPL_DUMMY_PROPERTY_LISTENER( ScDPLevel )
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
